derive_deftly_template_ConstantTimeEq

Macro derive_deftly_template_ConstantTimeEq 

macro_rules! derive_deftly_template_ConstantTimeEq {
    ({ $($driver:tt)* } [$($aoptions:tt)*] ($($future:tt)*) $($tpassthrough:tt)*) => { ... };
    ($($wrong:tt)*) => { ... };
}
Derives subtle::ConstantTimeEq on structs for which all fields already implement it. Note that this does NOT work on fields which are arrays of type T, even if T implements subtle::ConstantTimeEq. Arrays do not directly implement subtle::ConstantTimeEq and instead dereference to a slice, [T], which does. See subtle!114 for a possible future resolution.

This is a derive_deftly template. Do not invoke it directly. To use it, write: #[derive(Deftly)] #[derive_deftly(ConstantTimeEq)].