pub struct ExpandedKeypair {
pub(crate) secret: ExpandedSecretKey,
pub(crate) public: PublicKey,
}Expand description
A variant of Keypair containing an ExpandedSecretKey.
In the Tor protocol, we use this type for blinded onion service identity keys
(KS_hs_blind_id). Since their scalar values are computed, rather than taken
directly from a
SHA-512 transformation of a SecretKey, we cannot use the regular Keypair
type.
Fields
secret: ExpandedSecretKeyThe secret part of the key.
public: PublicKeyThe public part of this key.
NOTE: As with ed25519_dalek::SigningKey, this public key must be
the public key matching secret. Putting a different public key in
here would enable a class of attacks against ed25519 and enable secret
key recovery.
Implementations
Sourceimpl ExpandedKeypair
impl ExpandedKeypair
Sourcepub fn sign(&self, message: &[u8]) -> Signature
pub fn sign(&self, message: &[u8]) -> Signature
Compute a signature over a message using this keypair.
Sourcepub fn to_secret_key_bytes(&self) -> [u8; 64]
pub fn to_secret_key_bytes(&self) -> [u8; 64]
Return a representation of the secret key in this keypair.
(Since it is an expanded secret key, we represent it as its scalar part followed by its hash_prefix.)
Sourcepub fn from_secret_key_bytes(bytes: [u8; 64]) -> Option<Self>
pub fn from_secret_key_bytes(bytes: [u8; 64]) -> Option<Self>
Reconstruct a key from its byte representation as returned by
to_secret_key_bytes().
Return None if the input cannot be the output of to_secret_key_bytes().