pub struct ValidatableRsaSignature {
key: PublicKey,
sig: Vec<u8>,
expected_hash: Vec<u8>,
}Expand description
An RSA signature plus all the information needed to validate it.
Fields
key: PublicKeyThe key that allegedly signed this signature
sig: Vec<u8>The signature in question
expected_hash: Vec<u8>The value we expect to find that the signature is a signature of.
Implementations