CautiousRng

Struct CautiousRng 

pub struct CautiousRng;
An exceptionally cautious wrapper for SysRng

Ordinarily, one trusts SysRng. But we want Arti to run on a wide variety of platforms, and the chances of a bogus SysRng increases the more places we run. This Rng combines SysRng with several other entropy sources, in an attempt to reduce the likelihood of creating compromised keys.1

This Rng is slower than SysRng.

Panics

This rng will panic if SysRng fails; but that’s the only sensible behavior for a cryptographic-heavy application like ours.


  1. Who else remembers CVE-2008-0166