pub struct CtByteArray<const N: usize>(/* private fields */);Expand description
A byte array of length N for which comparisons are performed in constant time.
Limitations
It is possible to avoid constant time comparisons here, just by using the
as_ref() and as_mut() methods. They should therefore be approached with
some caution.
(The decision to avoid implementing Deref/DerefMut is deliberate.)